package com.muyu.event.process.basic;

import org.springframework.context.ApplicationListener;
import org.springframework.stereotype.Component;

/**
 * @Author: zi run
 * @Date 2024/9/30 15:37
 * @Description 基础事件处理器
 */
@Component
public class BasicEventHandler<T> implements ApplicationListener<BasicEvent<T>> {

    /**
     * 具体事件监听器
     */
    private final BasicEventListener<T> listener;

    /**
     * 构造函数，用于注入具体事件监听器
     *
     * @param listener 具体事件监听器
     */
    public BasicEventHandler(BasicEventListener<T> listener) {
        this.listener = listener;
    }

    /**
     * 处理应用事件
     *
     * @param event 事件对象
     */
    @Override
    public void onApplicationEvent(BasicEvent<T> event) {
        listener.onEvent(event);
    }
}